/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef sblnh
#define sblnh

#include <con.h>
#include <QString>

class sbln 
<%
	public:
		sbln();
		QString kidlgz;
		QString kitzjl;
		QString prmz;
%>;

#endif

